## Copyright 2014-2016 Oliver Heimlich
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, see <http://www.gnu.org/licenses/>.

## -*- texinfo -*-
## @documentencoding UTF-8
## @defmethod {@@infsupdec} pow2 (@var{X})
## 
## Compute @code{2^x} for all numbers in @var{X}.
##
## Accuracy: The result is a tight enclosure.
##
## @example
## @group
## pow2 (infsupdec (5))
##   @result{} ans = [32]_com
## @end group
## @end example
## @seealso{@@infsupdec/log2, @@infsupdec/pow, @@infsupdec/pow10, @@infsupdec/exp}
## @end defmethod

## Author: Oliver Heimlich
## Keywords: interval
## Created: 2014-10-13

function result = pow2 (x)

if (nargin ~= 1)
    print_usage ();
    return
endif

result = newdec (pow2 (x.infsup));
## pow2 is defined and continuous everywhere
result.dec = min (result.dec, x.dec);

endfunction

%!# from the documentation string
%!assert (isequal (pow2 (infsupdec (5)), infsupdec (32)));
